// Layer Shader Enum header
//
// This file is auto-generated by cmake, don't edit it.

absval = 0,
batchnorm = 1,
batchnorm_pack4 = 2,
concat = 3,
concat_pack4 = 4,
concat_pack4to1 = 5,
convolution = 6,
convolution_1x1s1d1 = 7,
convolution_1x1s1d1_cm = 8,
convolution_3x3s1d1_winograd23_transform_input = 9,
convolution_3x3s1d1_winograd23_transform_output = 10,
convolution_3x3s1d1_winograd43_transform_input = 11,
convolution_3x3s1d1_winograd43_transform_output = 12,
convolution_3x3s1d1_winograd_gemm = 13,
convolution_gemm = 14,
convolution_gemm_cm = 15,
convolution_pack1to4 = 16,
convolution_pack1to4_1x1s1d1 = 17,
convolution_pack1to4_3x3s1d1_winograd_gemm = 18,
convolution_pack1to4_gemm = 19,
convolution_pack4 = 20,
convolution_pack4_1x1s1d1 = 21,
convolution_pack4_3x3s1d1_winograd23_transform_input = 22,
convolution_pack4_3x3s1d1_winograd23_transform_output = 23,
convolution_pack4_3x3s1d1_winograd43_transform_input = 24,
convolution_pack4_3x3s1d1_winograd43_transform_output = 25,
convolution_pack4_3x3s1d1_winograd_gemm = 26,
convolution_pack4_gemm = 27,
convolution_pack4to1 = 28,
convolution_pack4to1_1x1s1d1 = 29,
convolution_pack4to1_3x3s1d1_winograd_gemm = 30,
convolution_pack4to1_gemm = 31,
convolution_winograd_gemm_cm = 32,
crop = 33,
crop_pack1to4 = 34,
crop_pack4 = 35,
crop_pack4to1 = 36,
deconvolution = 37,
deconvolution_col2im = 38,
deconvolution_gemm = 39,
deconvolution_gemm_cm = 40,
deconvolution_pack1to4 = 41,
deconvolution_pack1to4_gemm = 42,
deconvolution_pack4 = 43,
deconvolution_pack4_col2im = 44,
deconvolution_pack4_gemm = 45,
deconvolution_pack4to1 = 46,
deconvolution_pack4to1_gemm = 47,
dropout = 48,
eltwise = 49,
elu = 50,
flatten = 51,
flatten_pack1to4 = 52,
flatten_pack4 = 53,
innerproduct = 54,
innerproduct_gemm = 55,
innerproduct_gemm_wp1to4 = 56,
innerproduct_gemm_wp4 = 57,
innerproduct_gemm_wp4to1 = 58,
innerproduct_pack1to4 = 59,
innerproduct_pack4 = 60,
innerproduct_pack4to1 = 61,
innerproduct_reduce_sum8 = 62,
innerproduct_reduce_sum8_pack4 = 63,
innerproduct_sum8 = 64,
innerproduct_sum8_pack1to4 = 65,
innerproduct_sum8_pack4 = 66,
innerproduct_sum8_pack4to1 = 67,
lrn_norm = 68,
lrn_norm_across_channel_pack4 = 69,
lrn_norm_within_channel_pack4 = 70,
lrn_square_pad = 71,
lrn_square_pad_across_channel_pack4 = 72,
lrn_square_pad_within_channel_pack4 = 73,
pooling = 74,
pooling_adaptive = 75,
pooling_adaptive_pack4 = 76,
pooling_global_reduce_max = 77,
pooling_global_reduce_max_first = 78,
pooling_global_reduce_max_first_pack4 = 79,
pooling_global_reduce_max_last = 80,
pooling_global_reduce_max_last_pack4 = 81,
pooling_global_reduce_max_pack4 = 82,
pooling_global_reduce_sum = 83,
pooling_global_reduce_sum_first = 84,
pooling_global_reduce_sum_first_pack4 = 85,
pooling_global_reduce_sum_last = 86,
pooling_global_reduce_sum_last_pack4 = 87,
pooling_global_reduce_sum_pack4 = 88,
pooling_pack4 = 89,
prelu = 90,
prelu_pack4 = 91,
relu = 92,
reshape = 93,
reshape_pack1to4 = 94,
reshape_pack4 = 95,
reshape_pack4to1 = 96,
scale = 97,
scale_pack4 = 98,
sigmoid = 99,
slice = 100,
slice_pack1to4 = 101,
slice_pack4 = 102,
softmax_div_sum = 103,
softmax_div_sum_pack4 = 104,
softmax_exp_sub_max = 105,
softmax_exp_sub_max_pack4 = 106,
softmax_reduce_max = 107,
softmax_reduce_max_pack4 = 108,
softmax_reduce_sum = 109,
softmax_reduce_sum_pack4 = 110,
tanh = 111,
binaryop = 112,
binaryop_broadcast = 113,
binaryop_broadcast_pack1to4 = 114,
binaryop_broadcast_pack4 = 115,
binaryop_pack4 = 116,
unaryop = 117,
convolutiondepthwise = 118,
convolutiondepthwise_group = 119,
convolutiondepthwise_group_pack1to4 = 120,
convolutiondepthwise_group_pack4 = 121,
convolutiondepthwise_group_pack4to1 = 122,
convolutiondepthwise_pack4 = 123,
padding = 124,
padding_3d = 125,
padding_3d_pack4 = 126,
padding_pack1to4 = 127,
padding_pack4 = 128,
padding_pack4to1 = 129,
normalize_coeffs = 130,
normalize_coeffs_pack4 = 131,
normalize_norm = 132,
normalize_norm_pack4 = 133,
normalize_reduce_sum4_fp16_to_fp32 = 134,
normalize_reduce_sum4_fp16_to_fp32_pack4 = 135,
normalize_reduce_sum4_fp32 = 136,
normalize_reduce_sum4_fp32_pack4 = 137,
permute = 138,
permute_pack1to4 = 139,
permute_pack4 = 140,
permute_pack4to1 = 141,
priorbox = 142,
priorbox_mxnet = 143,
interp = 144,
interp_bicubic = 145,
interp_bicubic_coeffs = 146,
interp_bicubic_pack4 = 147,
interp_pack4 = 148,
deconvolutiondepthwise = 149,
deconvolutiondepthwise_group = 150,
deconvolutiondepthwise_group_pack1to4 = 151,
deconvolutiondepthwise_group_pack4 = 152,
deconvolutiondepthwise_group_pack4to1 = 153,
deconvolutiondepthwise_pack4 = 154,
shufflechannel = 155,
shufflechannel_pack4 = 156,
instancenorm_coeffs = 157,
instancenorm_coeffs_pack4 = 158,
instancenorm_norm = 159,
instancenorm_norm_pack4 = 160,
instancenorm_reduce_mean = 161,
instancenorm_reduce_mean_pack4 = 162,
instancenorm_reduce_sum4_fp16_to_fp32 = 163,
instancenorm_reduce_sum4_fp16_to_fp32_pack4 = 164,
instancenorm_reduce_sum4_fp32 = 165,
instancenorm_reduce_sum4_fp32_pack4 = 166,
instancenorm_sub_mean_square = 167,
instancenorm_sub_mean_square_pack4 = 168,
clip = 169,
reorg = 170,
reorg_pack1to4 = 171,
reorg_pack4 = 172,
quantize = 173,
quantize_pack4 = 174,
dequantize = 175,
dequantize_pack4 = 176,
packing = 177,
packing_int8 = 178,
packing_pack1to4 = 179,
packing_pack1to4_int8 = 180,
packing_pack4to1 = 181,
packing_pack4to1_int8 = 182,
requantize = 183,
requantize_pack4 = 184,
cast_fp16_to_fp32 = 185,
cast_fp16_to_fp32_pack4 = 186,
cast_fp32_to_fp16 = 187,
cast_fp32_to_fp16_pack4 = 188,
hardsigmoid = 189,
selu = 190,
hardswish = 191,
pixelshuffle = 192,
pixelshuffle_pack4 = 193,
pixelshuffle_pack4to1 = 194,
deepcopy = 195,
deepcopy_pack4 = 196,
mish = 197,
swish = 198,
gemm = 199,
gemm_cm = 200,
layernorm_coeffs = 201,
layernorm_coeffs_pack4 = 202,
layernorm_norm = 203,
layernorm_norm_pack4 = 204,
layernorm_reduce_mean = 205,
layernorm_reduce_mean_pack4 = 206,
layernorm_reduce_sum4_fp16_to_fp32 = 207,
layernorm_reduce_sum4_fp16_to_fp32_pack4 = 208,
layernorm_reduce_sum4_fp32 = 209,
layernorm_reduce_sum4_fp32_pack4 = 210,
layernorm_sub_mean_square = 211,
layernorm_sub_mean_square_pack4 = 212,
multiheadattention_qk_cross = 213,
multiheadattention_qk_cross_pack1to4 = 214,
multiheadattention_qk_cross_pack4 = 215,
multiheadattention_qk_cross_pack4to1 = 216,
multiheadattention_qkv_cross = 217,
multiheadattention_qkv_cross_pack1to4 = 218,
multiheadattention_qkv_cross_pack4 = 219,
multiheadattention_qkv_cross_pack4to1 = 220,
gelu = 221,
convolution1d = 222,
convolution1d_pack1to4 = 223,
convolution1d_pack4 = 224,
convolution1d_pack4to1 = 225,
erf = 226,
celu = 227,
rmsnorm_coeffs = 228,
rmsnorm_coeffs_pack4 = 229,
rmsnorm_norm = 230,
rmsnorm_norm_pack4 = 231,
rmsnorm_square = 232,
rmsnorm_square_pack4 = 233,
convert_ycbcr = 234,
vulkan_activation = 235,

